==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/PolicyV1beta1PodSecurityPolicyListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PolicyV1beta1PodSecurityPolicyListFluent<A extends PolicyV1beta1PodSecurityPolicyListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,PolicyV1beta1PodSecurityPolicy item);
    public A setToItems(int index,PolicyV1beta1PodSecurityPolicy item);
    public A addToItems(PolicyV1beta1PodSecurityPolicy... items);
    public A addAllToItems(Collection<PolicyV1beta1PodSecurityPolicy> items);
    public A removeFromItems(PolicyV1beta1PodSecurityPolicy... items);
    public A removeAllFromItems(Collection<PolicyV1beta1PodSecurityPolicy> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PolicyV1beta1PodSecurityPolicy> getItems();
    public List<PolicyV1beta1PodSecurityPolicy> buildItems();
    public PolicyV1beta1PodSecurityPolicy buildItem(int index);
    public PolicyV1beta1PodSecurityPolicy buildFirstItem();
    public PolicyV1beta1PodSecurityPolicy buildLastItem();
    public PolicyV1beta1PodSecurityPolicy buildMatchingItem(io.kubernetes.client.fluent.Predicate<PolicyV1beta1PodSecurityPolicyBuilder> predicate);
    public A withItems(List<PolicyV1beta1PodSecurityPolicy> items);
    public A withItems(PolicyV1beta1PodSecurityPolicy... items);
    public Boolean hasItems();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItem();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItemLike(PolicyV1beta1PodSecurityPolicy item);
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> setNewItemLike(int index,PolicyV1beta1PodSecurityPolicy item);
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editItem(int index);
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editFirstItem();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editLastItem();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<PolicyV1beta1PodSecurityPolicyBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,PolicyV1beta1PodSecurityPolicyFluent<PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/PolicyV1beta1PodSecurityPolicyListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PolicyV1beta1PodSecurityPolicyListFluent<A extends PolicyV1beta1PodSecurityPolicyListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,PolicyV1beta1PodSecurityPolicy item);
    public A setToItems(int index,PolicyV1beta1PodSecurityPolicy item);
    public A addToItems(PolicyV1beta1PodSecurityPolicy... items);
    public A addAllToItems(Collection<PolicyV1beta1PodSecurityPolicy> items);
    public A removeFromItems(PolicyV1beta1PodSecurityPolicy... items);
    public A removeAllFromItems(Collection<PolicyV1beta1PodSecurityPolicy> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PolicyV1beta1PodSecurityPolicy> getItems();
    public List<PolicyV1beta1PodSecurityPolicy> buildItems();
    public PolicyV1beta1PodSecurityPolicy buildItem(int index);
    public PolicyV1beta1PodSecurityPolicy buildFirstItem();
    public PolicyV1beta1PodSecurityPolicy buildLastItem();
    public PolicyV1beta1PodSecurityPolicy buildMatchingItem(io.kubernetes.client.fluent.Predicate<PolicyV1beta1PodSecurityPolicyBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<PolicyV1beta1PodSecurityPolicyBuilder> predicate);
    public A withItems(List<PolicyV1beta1PodSecurityPolicy> items);
    public A withItems(PolicyV1beta1PodSecurityPolicy... items);
    public Boolean hasItems();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItem();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItemLike(PolicyV1beta1PodSecurityPolicy item);
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> setNewItemLike(int index,PolicyV1beta1PodSecurityPolicy item);
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editItem(int index);
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editFirstItem();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editLastItem();
    public PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<PolicyV1beta1PodSecurityPolicyBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadata();
    public PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,PolicyV1beta1PodSecurityPolicyFluent<PolicyV1beta1PodSecurityPolicyListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<PolicyV1beta1PodSecurityPolicyListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
